@@ -1,4 +1,9 @@
 package Log::Contextual::Easy::Default;
+$Log::Contextual::Easy::Default::VERSION = '0.006001';
+# ABSTRACT: Import all logging methods with WarnLogger as default
+
+use strict;
+use warnings;
 
 use base 'Log::Contextual';
 
@@ -19,10 +24,6 @@ sub default_import { qw(:dlog :log ) }
 
 __END__
 
-=head1 NAME
-
-Log::Contextual::Easy::Default - Import all logging methods with WarnLogger as default
-
 =head1 SYNOPSIS
 
 In your module:
@@ -59,8 +60,6 @@ For what C<::Default> implies, see L<Log::Contextual/-default_logger>.
 
 =over 4
 
-=item L<Log::Contextual>
-
 =item L<Log::Contextual::Easy::Package>
 
 =back
