@@ -1,4 +1,7 @@
 package Log::Contextual::SimpleLogger;
+$Log::Contextual::SimpleLogger::VERSION = '0.006001';
+# ABSTRACT: Super simple logger made for playing with Log::Contextual
+
 
 use strict;
 use warnings;
@@ -57,10 +60,6 @@ sub _log {
 
 __END__
 
-=head1 NAME
-
-Log::Contextual::SimpleLogger - Super simple logger made for playing with Log::Contextual
-
 =head1 SYNOPSIS
 
  use Log::Contextual::SimpleLogger;
@@ -182,17 +181,5 @@ level is enabled.
 
  say q{fatal'ing} if $l->is_fatal;
 
-=head1 AUTHOR
-
-See L<Log::Contextual/"AUTHOR">
-
-=head1 COPYRIGHT
-
-See L<Log::Contextual/"COPYRIGHT">
-
-=head1 LICENSE
-
-See L<Log::Contextual/"LICENSE">
-
 =cut
 
