@@ -1,4 +1,6 @@
 package Log::Contextual::TeeLogger;
+$Log::Contextual::TeeLogger::VERSION = '0.006001';
+# ABSTRACT: Output to more than one logger
 
 use strict;
 use warnings;
@@ -42,10 +44,6 @@ sub new {
 
 __END__
 
-=head1 NAME
-
-Log::Contextual::TeeLogger - Output to more than one logger
-
 =head1 SYNOPSIS
 
  use Log::Contextual::SimpleLogger;
@@ -163,17 +161,5 @@ level is enabled.
 
  say q{fatal'ing} if $l->is_fatal;
 
-=head1 AUTHOR
-
-See L<Log::Contextual/"AUTHOR">
-
-=head1 COPYRIGHT
-
-See L<Log::Contextual/"COPYRIGHT">
-
-=head1 LICENSE
-
-See L<Log::Contextual/"LICENSE">
-
 =cut
 
